##====================================================================##
##==Purpose: To get slope (method=0), intercept (method=1), mean    ==## 
##==         (method=2) of probesets for various time intervals     ==##     
##==                                                                ==##
##==Input:                                                          ==##
##==  *txt.info                                                     ==##
##==  Specifying name of the *.txt file which contains the          ==##
##==  microarrays id.                                               ==##
##==  For example, the microarrays for batch 1 is in "data/csv/     ==##
##==  microarrayID250.168.batch1/microarrayID250.168.batch1         ==## 
##==  expression.xls", then txt.info is                             ==##
##==  "microarrayID250.168.batch"                                   ==##
##==  *data/Rdata/microarray/txt.info.Rdata                         ==##
##==  -Xraw: A matrix with rows corresponding to probesets, and the ==##
##==         columns the microarrays of patients at different time  ==##
##==         points.                                                ==##
##==  The follow R objects are used to identify the columns of      ==## 
##==  Xraw.                                                         ==##  
##==  -patient.id: A vector of patients ID                          ==##
##==  -microarray.id: A vector of microarray ID                     ==##
##==  -batch: A vector of batch ID                                  ==##
##==  -hours.si: A vector of the timing which the microarray was    ==##
##==             collected (in hours).                              ==##
##==  *Additional parameters                                        ==##
##==  -constant, e.g. 10                                            ==##
##==  -min_hours, e.g. 12                                           ==##
##==  -max_hours, e.g. 250                                          ==##                                
##==  -method, e.g. 0                                               ==##
##==                                                                ==##
##==Sub-routines:                                                   ==##
##==  *Function to generate the slope matrix                        ==##
##==  code/2_normalization/mtx_linfit.R                             ==##
##==                                                                ==##
##==Output:                                                         ==##
##==  gDat, a matrix with columns corresponding to patients and     ==## 
##==  rows the probests. It will be stored in data/Rdata/microarray ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

##Function to compute the Slope (WPEC)/Intercept, mtx.linfit
source("code/2_normalization/mtx_linfit.R")

##Information regarding microarray id, patient id, hours and batch
load(file=paste("data/Rdata/microarray/",txt.info,".Rdata",sep=""))

gDat<-NULL  ##Slope/WPEC matrix
##Compute the quantity for each patient
for(k in unique(patient.id)){
  ##Identify the microarrays associated with the patient given the time interval  
  valid<-which(patient.id==k & hours.si>=min_hours & hours.si<=max_hours)
  if(length(valid)>2){
    if(method == 0) {
      ##Linear regression:
      tmp <- mtx.linfit(log2(Xraw[,valid]+constant),hours.si[valid],"slope");
	}else if (method ==1) {
      ##Linear regression intercept:
	  tmp <- mtx.linfit(log2(Xraw[,valid]+constant),hours.si[valid],"offset");
	}else if (method ==2) {
      ##Mean value:
	  tmp <- rowMeans(log2(Xraw[,valid]+constant),dims=1);
	} 	
    ##Collect the data
	gDat <- cbind(gDat,tmp)
	colnames(gDat)[ncol(gDat)]<-k  
  }											
}

if(method == 0) {
  ##Linear regression
  save(gDat,file=paste("data/Rdata/microarray/",txt.info," Slope (",min_hours,"-",max_hours,").Rdata",sep=""))

}else{
  save(gDat,file=paste("data/Rdata/microarray/",txt.info," (",min_hours,"-",max_hours,").",method,".Rdata",sep=""))

}

