##====================================================================##
##==Purpose: To normalize the micorarrays with dChip                ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  txt.info: Specifying name of the *.txt file which contains    ==##
##==            the microarrays id.                                 ==##
##==            For example, the microarrays for batch is in        ==##
##==            "microarrayID250.168.batch1.txt", then              ==##
##==            txt.info is "microarrayID250.168.batch"             ==##
##==                                                                ==##
##==Sub-routines:                                                   ==##
##==  *Generate plots for paper                                     ==##
##==  code/2_normalization/gen.dChip.ini.R                          ==##
##==                                                                ==##
##==Output:                                                         ==## 
##==  Exports the normalized expression data to                     ==##
##==  data/csv/txt.nameBATCHID                                      ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##


##Set working directory
setwd(wkdir.backslash)
##Source the code to automate normalization via dChip
source("code/2_normalization/gen.dChip.ini.R")

##==The code to normalize the microarray data 
for(phaseid in 1:4){
  
  ##Append the batch id (i.e. phaseid) to txt.name
  txt.name<-paste(txt.info,phaseid,sep="")
  dir.create(paste("data\\csv\\",txt.name,sep=""))
  gen.dChip.ini(DATA_PATH=paste("data\\CEL\\",txt.name,".txt",sep=""),
                WORKING_DIR=paste("data\\csv\\",txt.name,sep=""),
                CDF_FILE="data\\CEL\\HG-U133_Plus_2.cdf",
                wkdir=wkdir.backslash,
                dChip.dir="data\\CEL",
                ini.path="data\\CEL\\dChipDefault.ini",
                ini.name=paste(txt.name,".ini",sep=""))
  print(paste("Batch/Phase:",phaseid))
  
  Sys.sleep(10)	
  system("taskkill /IM cmd.exe")	
  
  uncompleted<-TRUE
  count<-1
  while(uncompleted){
    Sys.sleep(60)
    cat("\r","Count:",count)
    count<-count+1
    uncompleted<-length(dir(paste("data\\csv\\",txt.name,sep="")))<3
  }
  cat("\n")
  system("taskkill /IM dchip.exe")    

}

