##====================================================================##
##==Purpose: This function automate the dChip normalization         ==##
##==         procedure via R                                        ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  DATA_PATH: Specifying the path of the *.txt file which        ==##
##==             contains the microarrays id                        ==##
##==  WORKING_DIR: Specifying the directory to save the normalized  ==##
##==               expression                                       ==##
##==  CDF_FILE: Specifying the path of the the *.cdf file           ==##
##==  wkdir: The working directory of the project                   ==##
##==  dChip.dir: Specify the directory where the dChip software is  ==##
##==             installed                                          ==##
##==  ini.path: Specify the path of the *.ini file which contains   ==##
##==            the default settings                                ==##
##==  ini.name: Specify the name of the *.ini file for the          ==##
##==            normalization                                       ==##
##==                                                                ==##
##==Output:                                                         ==## 
##==  Exports the normalized expression data to WORKING_DIR         ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

gen.dChip.ini<-function(DATA_PATH=paste("data\\CEL\\microarrayID250.168.batch",phaseid,".txt",sep=""),
                        WORKING_DIR=paste("data\\csv\\microarrayID250.168.batch",phaseid,sep=""),
                        CDF_FILE="data\\CEL\\HG-U133_Plus_2.cdf",
                        wkdir=paste(strsplit(getwd(),split="/")[[1]],collapse="\\"),
                        dChip.dir="data\\CEL",
                        ini.path="data\\CEL\\dChipDefault.ini",
                        ini.name=paste("microarrayID250.168.batch",phaseid,".ini",sep="")){
  
  ##Set the working directory    
  print(wkdir)
  setwd(wkdir)
  ##Read in the settings for dChip from the *.ini
  dChip.ini<-scan(ini.path,what="character",sep="\n")

  ##Change the parameters of *.ini accordingly
  if(!is.null(DATA_PATH)){
    id1<-grep("DATA_PATH",dChip.ini)
    dChip.ini[id1]<-paste("DATA_PATH=",wkdir,"\\",DATA_PATH,sep="")
  }
  if(!is.null(WORKING_DIR)){
    id1<-grep("WORKING_DIR",dChip.ini)
    dChip.ini[id1]<-paste("WORKING_DIR=",wkdir,"\\",WORKING_DIR,sep="")
  }
  if(!is.null(CDF_FILE)){
    id1<-grep("CDF_FILE",dChip.ini)
    dChip.ini[id1]<-paste("CDF_FILE=",wkdir,"\\",CDF_FILE,sep="")
  }
  
  ##Write the new *.ini file
  write.table(matrix(dChip.ini,ncol=1),
              file=paste(dChip.dir,"\\",ini.name,sep=""),
              row.names=FALSE,col.names=FALSE,quote=FALSE)

  ##Write a *.bat file to execute the normalization
#  cat('cd "',substring(paste(wkdir,"\\",dChip.dir,sep=""),4,nchar(paste(wkdir,"\\",dChip.dir,sep=""))),'" \n',sep="",
#      file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=FALSE)#,append=TRUE)
#  cat("cd \\ \n",
#      file=paste(dChip.dir,"\\",ini.name,".bat",sep=""))
      
  print(substring(wkdir,1,2)=="D:")
  if(substring(wkdir,1,2)=="D:"){
    cat("cd ",substring(wkdir,1,2)," \n",
        file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=TRUE)#
#    cat("cd \\ \n",
#        file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=TRUE)

    cat('cd /D "',paste(wkdir,"\\",dChip.dir,sep=""),'" \n',sep="",
        file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=FALSE)

  }else{
    cat('cd "',paste(wkdir,"\\",dChip.dir,sep=""),'" \n',sep="",
        file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=TRUE)
  }

  cat("dchip -ini ",ini.name," -norm -model -export -log \n",sep="",
      file=paste(dChip.dir,"\\",ini.name,".bat",sep=""),append=TRUE)

  ##Run the *.bat 
  shell.exec(paste(wkdir,"\\",dChip.dir,"\\",ini.name,".bat",sep=""))

}



