##====================================================================##
##==Purpose: Reproducibility of the analysis via cross-validation   ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  *split.id                                                     ==##
##==  *subset.id                                                    ==##
##==  *phase.id                                                     ==##
##==  *L: a data frame with columns corresponding to patient_id,    ==##
##==  cluster (i.e. ocMOF),batch and sex.                           ==##
##==  *Additional parameters                                        ==##
##==  -constant, e.g. 10                                            ==##
##==  -min_hours.2, e.g. 12                                         ==##
##==  -max_hours.2, e.g. 250                                        ==## 
##==  -min_hours.2, e.g. 12  [Only for the test subset]             ==##
##==  -max_hours.2, e.g. 180 [Only for the test subset]             ==##
##==  -bypassnorm, logical, T=by pass normalization by calling dchip==##
##==  *data/Rdata/settings.Rdata                                    ==##
##==  Contains R objects which are the settings, bypassnorm &       ==##
##==  pngPlot                                                       ==##  
##==                                                                ==##
##==Output:                                                         ==##
##==  *ocMOF.disc, ocMOF.vali                                       ==##
##==  The ocMOF groupings of the discovery and validation subsets   ==##
##==  *phase.disc, phase.vali                                       ==##
##==  The phase ids of the discovery and validation subsets         ==##
##==  *sex.disc, sex.vali                                           ==##
##==  The sex of the discovery and validation subsets               ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

load(file="data/Rdata/settings.Rdata")
#load subset 1 data in dat[[1]] and subset 2 data in dat[[2]]
#colnames(dat[[i]]) gives correponding array ids
dat = array(list(NA),2)
for(subset.id in 1:length(dat)){
 	for(phase.id in 1:4){
		if(!bypassnorm){	
          ##Using microarray that is normalized locally on the machine   
  		  datatmp = read.table(sprintf("./data/csv/split%d_subset%d_phase%d/split%d_subset%d_phase%d expression.xls",split.id,subset.id,phase.id,split.id,subset.id,phase.id),sep="\t",header=TRUE)
		}else{
          ##Using normalized microarray which is used by the paper
		  datatmp = read.table(sprintf("./data/normarray/split%d_subset%d_phase%d/split%d_subset%d_phase%d expression.xls",split.id,subset.id,phase.id,split.id,subset.id,phase.id),sep="\t",header=TRUE)
		}
		
		rownames(datatmp) = datatmp[,1]
		datatmp = datatmp[,2:(ncol(datatmp)-1)]
		if(phase.id==1){ 
			dataall = datatmp
		}else{
			if(all(rownames(dataall)==rownames(datatmp))){
				dataall = cbind(dataall,datatmp)
			}else{
				stop("The probesets ids are not matching up")
			}
		}
		print(sprintf("subset %d: phase %d data loaded...",subset.id,phase.id))
	}
	dat[[subset.id]] = log2(dataall+constant)
	rm(dataall,datatmp)
}

#subset 1
m.1 <- colnames(dat[[1]])	                    #microarray ids
p.1 <- patient.id[match(m.1,microarray.id)]	#correponding patient ids
h.1 <- hours.si[match(m.1,microarray.id)]	    #correpsonding hours.si
pat.1 <- as.character(unique(p.1))			#unique patients in subset 1
X.disc = matrix(0,54675,length(pat.1))	    #slopes
colnames(X.disc) <- pat.1				    #ith column of X.disc corresponds to pat.1[i]
rownames(X.disc) <- rownames(dat[[1]])
for(i in 1:length(pat.1)){
 	gexptmp = dat[[1]][,pat.1[i]==p.1]	#gene expression for ith patient
	hsitmp = h.1[pat.1[i]==p.1]			#corresponding hours.si
	X.disc[,i] = mtx.linfit(as.matrix(gexptmp),hsitmp,method="slope") #slopes
}
#ocMOF, batch, and sex for patients in subset 1
ocMOF.disc = matrix(L$cluster[match(colnames(X.disc),L$patient_id)],length(pat.1),1)
phase.disc = matrix(L$batch[match(colnames(X.disc),L$patient_id)],length(pat.1),1)
sex.disc = matrix(L$sex[match(colnames(X.disc),L$patient_id)],length(pat.1),1)


#subset 2
m.2 <- colnames(dat[[2]])	#microarray ids
p.2 <- patient.id[match(m.2,microarray.id)]	#correponding patient ids
h.2 <- hours.si[match(m.2,microarray.id)]	    #correpsonding hours.si
pat.2 <- as.character(unique(p.2))			#unique patients in subset 2
X.vali = matrix(0,54675,length(pat.2))    	#slopes 
colnames(X.vali) <- pat.2				        #ith column of data.slope2 corresponds to pat.2[i]
rownames(X.vali) <- rownames(dat[[2]])
for(i in 1:length(pat.2)){
 	gexptmp = dat[[2]][,pat.2[i]==p.2]	#gene expression for ith patient
 	hsitmp = h.2[pat.2[i]==p.2]			#corresponding hours.si
	if(sum(hsitmp>=min_hours.2 & hsitmp<=max_hours.2)>=3){  
		X.vali[,i] = mtx.linfit(as.matrix(gexptmp),hsitmp,method="slope") #slopes
	}else{
		X.vali[,i] = NA #slopes
	}
}
##Keep those columns which do not have NA	
keep.col<-which(!apply(X.vali,2,function(x) all(is.na(x))))
X.vali<-X.vali[,keep.col]	
#ocMOF, batch, and sex for patients in subset 2
ocMOF.vali = matrix(L$cluster[match(colnames(X.vali),L$patient_id)],ncol(X.vali),1)
phase.vali = matrix(L$batch[match(colnames(X.vali),L$patient_id)],ncol(X.vali),1)
sex.vali = matrix(L$sex[match(colnames(X.vali),L$patient_id)],ncol(X.vali),1)
rm(dat)
