##====================================================================##
##==Purpose: To identify patients whose arrays were burnt on        ==##
##==  different days.                                               ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  data/clinical_data/TRDB_TRAUMA-PT_DEMO_MICRO_SVRTY_RPT_200908 ==##
##==  24_105202.xls                                                 ==##
##==                                                                ==##
##==Output:                                                         ==##
##==  *data/Rdata/burnmDat.Rdata                                    ==##
##==  burnmDat, a data frame with columns corresponding to          ==##
##==  patient ids, microarray ids, batch/burnt ids and hours since  ==## 
##==  injury                                                        ==##
##==                                                                ==##
##==R library: gdata                                                ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu             ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

##==Read in microarray data 
library(gdata)
mDat<-read.xls("data/clinical_data/TRDB_TRAUMA-PT_DEMO_MICRO_SVRTY_RPT_20090824_105202.xls")

##Those with bad RNA quality
mDat<-mDat[mDat[,"HOURS_SINCE_INJURY"]>=12 & mDat[,"HOURS_SINCE_INJURY"]<=250,]
mDat<-mDat[mDat[,"RNA_QUAL"]>1,]


burnmDat<-mDat[,c("PATIENT_ID","MICROARRAY_ID","BATCH_ID","HOURS_SINCE_INJURY")]
save(burnmDat,file="data/Rdata/burnmDat.Rdata")