##====================================================================##
##==Purpose: Data quality issues and microarray collection          ==##
##==         timepoints by patients                                 ==##
##==                                                                ==##
##==Input:                                                          ==##
##==  *txt.info                                                     ==##
##==  Specifying name of the *.txt file which contains the          ==##
##==  microarrays id.                                               ==##
##==  *"data/Rdata/microarray/",txt.info," Slope (",min_hours,"-",  ==##
##==  max_hours,").Rdata"                                           ==##
##==  gDat, a matrix with columns corresponding to patients and     ==##
##==  rows the probests. The entries are the related to gene        ==##
##==  expressions.                                                  ==##
##==  *data/CEL/info.all.csv                                        ==##
##==  Table where the columns are patient ids, microarray ids,      ==##
##==  batch ids and hours since injury. Microarrays collected from  ==##
##==  hour 0 to 800 and no filtering based on RNA quality           ==##
##==  *Additional parameters                                        ==##
##==  -min_hours, e.g. 12                                           ==##
##==  -max_hours, e.g. 250                                          ==## 
##==                                                                ==## 
##==Figures for paper:                                              ==##
##==  *Scatter plot of microarray collection by patients            ==##
##==  plots/forpaper/Supplementary_Figure1_timepoints.pdf           ==## 
##==  *Heatmap of the correlation of WPEC between patients          ==##
##==  plots/forpaper/Supplementary_Figure2_dataissues.pdf           ==##
##==                                                                ==## 
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

##==Microarray collection timepoints by patients
##Information regarding microarray id, patient id, hours and batch
info.all<-read.table(file="data/CEL/info.all.csv",sep=",")

patient.id<-info.all[,"patient.id"]	
microarray.id<-paste("t",info.all[,"microarray.id"],sep="")
batch<-info.all[,"batch.id"]
hours.si<-info.all[,"hours.si"]

unique.pat = unique(patient.id)
unique.pat = sort(unique.pat)
pdf("plots/forpaper/Supplementary_Figure1_timepoints.pdf")
par(yaxt="n",xaxt="n",mar=c(5.5,5.5,1,1))
plot(hours.si[patient.id==unique.pat[1]],rep(1,sum(patient.id==unique.pat[1])),
type="p",xlim=c(-5,750),ylim = c(0,length(unique.pat)+5),
xlab="Hours since injury",ylab="Patients",cex.lab=2)
par(xaxt="s")
axis(side=1,at=seq(0,700,by=100),cex.axis=1.5)
for(i in 2:length(unique.pat)){
	points(hours.si[patient.id==unique.pat[i]],rep(i,sum(patient.id==unique.pat[i])))
}
dev.off()
rm(list=ls())

##==Data quality issues
txt.info<-"microarrayID250.168.batch"
min_hours<-12;
max_hours<-250;
load(file=paste("data/Rdata/microarray/",txt.info," Slope (",min_hours,"-",max_hours,").Rdata",sep=""))

pdf("plots/forpaper/Supplementary_Figure2_dataissues.pdf")
heatmap((cor(gDat)>0)*1,Rowv=NA,Colv=NA,col=c("black","grey"),symm=T,
labRow = NA, labCol=NA)
mtext("Patients",side=1,cex=2,line=2)
mtext("Patients",side=4,cex=2)
dev.off()
rm(list=ls())



