##====================================================================##
##==Purpose: Plot the heatmap of all 168 patients from hour 0 to 800==##
##==                                                                ==##
##==Figures for paper:                                              ==##
##==  plots/forpaper/Supplementary_Figure14_allArrays.png           ==## 
##==                                                                ==## 
##==Sub-routines:                                                   ==##
##==  code/2_normalization/ComputeWPEC.R                            ==##
##==                                                                ==## 
##== R library: gplots                                              ==##
##==                                                                ==##
##==Prepared by Chuen Seng Tan/John Storey/Keyur Desai              ==##
##==email: chuentan@princeton.edu/jstorey@princeton.edu/            ==##
##==       kdesai@princeton.edu                                     ==##
##====================================================================##

##==Identify the top 500
##Specifying the type of microarray data to look
type1<-"microarrayID250.168.batch Slope (12-250)"
output<-read.table(file=paste("data/csv/res.",type1,"adj.csv",sep=""),sep=",")
top500<-as.character(output[1:500,1])

##==Read in the microarray data and variables, e.g. patient id, microarray id and etc
print("Reading in 797 microarrays and variables")
info.all<-TRUE
txt.info<-"microarrayIDALL.168.batch"
source("code/2_normalization/Consolidatebatches.R",local=TRUE)

##==To convert days to the intended sampling days
idays<-c(0, 1, 4, 7, 14, 21, 28)
idays.168<-days.si
for(p.id in unique(patient.id)){
	valid<-which(patient.id==p.id)
	days<-days.si[valid]
	id<-c(1:length(idays))
	taken<-NULL
	for(i in sort(days)){
		if(i==0){
			not.taken<-id
		}else{
			not.taken<-id[!(id%in%taken)]
		}
		min.id<-which.min(abs(idays[not.taken]-i))
		idays.168[valid[days==i]]<-idays[not.taken[min.id]]
		taken<-c(taken,not.taken[min.id])
	}
}

##Plot the differences in the intended and actual sampling days
#plot(idays.168,idays.168-days.si)

##Manually identify those patients where the difference between intended sampling and days.si is greater than 1
pID<-unique(patient.id[which(abs(idays.168-days.si)>1)])
#for(p.id in pID){
#  valid<-which(patient.id==p.id)
#  print("===========================")
#  print(p.id)
#  patient.id[valid]
#  print(days.si[valid])
#  print(idays.168[valid])
#  print("===========================")
#}

##Manually change the time to the appropriate intended sampling days
  p.id<-501088
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0,  1,  4, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1,  4, 7, 14, 21)

  p.id<-17207778
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0,  1,  7,  4, 14))) stop("something wrong")
  idays.168[valid]<-c(0,  1,  4,  7, 14)

  p.id<-6738186
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0, 1, 7, 4))) stop("something wrong")
  idays.168[valid]<-c(0,  1,  4, 7)

  p.id<-18878883
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0,  1,  7,  4, 14, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4,  7, 14, 28)

  p.id<-11541392
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0,  1,  7,  4, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4,  7, 14, 21, 28)

  p.id<-8508630
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(0,  1,  7,  4, 14, 21))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4,  7, 14, 21)

  p.id<-7894880
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4,  7, 14, 21,28)

  p.id<-33426107
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4)

  p.id<-32475245
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1, 0, 4, 7))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7)

  p.id<-20340215
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7, 14)

  p.id<-1103804
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7, 14, 21, 28)

  p.id<-17889263
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14, 21))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7, 14, 21)

  p.id<-7799156
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7, 14, 21, 28)

  p.id<-14484685
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 21))) stop("something wrong")
  idays.168[valid]<-c(0,  1, 4, 7, 21)

  p.id<-18359204
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0))) stop("something wrong")
  idays.168[valid]<-c(0,  1)

  p.id<-29670554
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1, 0, 4, 7))) stop("something wrong")
  idays.168[valid]<-c(0, 1, 4, 7)

  p.id<-21098703
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1, 0))) stop("something wrong")
  idays.168[valid]<-c(0, 1)

  p.id<-8815978
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14))) stop("something wrong")
  idays.168[valid]<-c(0,  1,  4,  7, 14)

  p.id<-23237144
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0))) stop("something wrong")
  idays.168[valid]<-c(0,  1)

  p.id<-29060513
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4,  7, 14, 21))) stop("something wrong")
  idays.168[valid]<-c(0, 1,  4,  7, 14, 21)

  p.id<-25335818
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4, 14))) stop("something wrong")
  idays.168[valid]<-c(0, 1,  4,  14)

  p.id<-1274923
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1, 0, 4, 7))) stop("something wrong")
  idays.168[valid]<-c(0, 1,  4,  7)

#==To check that things are changed correctly
#for(p.id in pID){
#  valid<-which(patient.id==p.id)
#  print("===========================")
#  print(p.id)
#  patient.id[valid]
#  print(days.si[valid])
#  print(idays.168[valid])
#  print("===========================")
#}


##Manually identify those individuals where the ordering of intended sampling and days.si are not monotonic
#tmp<-NULL
#for(p.id in unique(patient.id)){
#  valid<-which(patient.id==p.id)
#  tmp<-c(tmp,all(order(patient.id[valid])==order(idays.168[valid])))
#}
#names(tmp)<-unique(patient.id)
#print("Identify those individuals where the ordering of intended sampling and days.si are not monotonic")
#which(tmp==FALSE)

##Manually change the time to the appropriate intended sampling days
  p.id<-32402266
  valid<-which(patient.id==p.id)
  idays.168[valid]
  days.si[valid]

  p.id<-32402266
  valid<-which(patient.id==p.id)
  if(!all(idays.168[valid]== c(1,  0,  4, 14, 21, 28))) stop("something wrong")
  idays.168[valid]<-c(0, 1,  4,  14, 21, 28)

##Now ordering of intended sampling and days.si are not monotonic
tmp<-NULL
for(p.id in unique(patient.id)){
  valid<-which(patient.id==p.id)
  tmp<-c(tmp,all(order(patient.id[valid])==order(idays.168[valid])))
}
names(tmp)<-unique(patient.id)
#print("Ordering of intended sampling and days.si are monotonic")
#print(table(tmp))
if(!all(tmp==TRUE)) stop("The ordering of the intended sampling and days.si are not monotonic")
#which(tmp==FALSE)

##Plot the differences in the intended and actual sampling days
#plot(idays.168,idays.168-days.si)

##Load the confounders for identifying the ocMOF groupings
load(file=paste("data/Rdata/dat.cfr.Rdata"))
##Order dat.cfr according to ocMOF grouping
grp<-dat.cfr[,"cluster"]
oMof<-order(grp)
dat.cfr<-dat.cfr[oMof,]

##Get the ocMOF groupings for the 797 microarrays, with the microarry id and intended sampling days
dat.cfr.168<-NULL
for(i in idays){
  valid<-which(idays.168==i)
  miID<-microarray.id[valid]
  paID<-patient.id[valid]

  ref<-dat.cfr[dat.cfr[,"patient_id"]%in%paID,"patient_id"]
  id<-match(ref,paID)
  paID<-paID[id]
  miID<-miID[id]
  if(!all(paID==ref)) stop("something is wrong")

  dat.cfr.168<-rbind(dat.cfr.168,cbind(dat.cfr[dat.cfr[,"patient_id"]%in%paID,],miID=I(miID),day=i))
  
}


##Just to check that the order of Xraw and microarray ids are the same
if(!all(colnames(Xraw)==microarray.id)){
  ref<-colnames(Xraw)
  id<-match(ref,microarray.id)
  microarray.id<-microarray.id[id]
  if(!all(microarray.id==ref)) stop("something is wrong")

  batch<-batch[id] 
  hours.si<-hours.si[id]
  days.si<-  days.si[id]
  patient.id<-patient.id[id]
}

##Get the order of Xraw according to dat.cfr.168 (which is ordered by ocMOF) 
tmpmm<-NULL
odat.col<-NULL
for(mm in dat.cfr.168[,"miID"]){
  tmpmm<-c(tmpmm,dat.cfr.168[dat.cfr.168[,"miID"]==mm,"patient_id"]==patient.id[which(microarray.id==mm)])
  odat.col<-c(odat.col,which(colnames(Xraw)==mm))
}
if(!all(tmpmm)) stop("The microarrays and patient ids are mixed up between dat.cfr.168 and patient.id/microarray.id")

##Get the right ordering of the microarrays
gDat<-Xraw[,odat.col]
if(!all(colnames(gDat)==dat.cfr.168[,"miID"]))  stop("Error in ordering")
rm(Xraw)

##Getting the color coding for ocMOF
ocMOF.col<-rep(0,nrow(dat.cfr.168))
ocMOF.col[dat.cfr.168[,"cluster"]==1]<-3
ocMOF.col[dat.cfr.168[,"cluster"]==2]<-4
ocMOF.col[dat.cfr.168[,"cluster"]==3]<-5
ocMOF.col[dat.cfr.168[,"cluster"]==4]<-6
ocMOF.col[dat.cfr.168[,"cluster"]==5]<-2

##Add na to the end of days to create the white space
dat1<-NULL
col1<-NULL
day1<-NULL
for(i in idays){
  valid<-which(dat.cfr.168[,"day"]==i)
  dat1<-cbind(dat1,as.matrix(gDat)[rownames(gDat)%in%top500,valid],rep(NA,500),rep(NA,500),rep(NA,500),rep(NA,500),rep(NA,500),rep(NA,500))
  day1<-c(day1,dat.cfr.168[valid,"day"],NA,NA,NA,NA,NA,NA)
  col1<-c(col1,ocMOF.col[valid],0,0,0,0,0,0)
}
rm(gDat,dat.cfr.168,ocMOF.col)

##Rank the slopes within each probeset
top500r<-as.matrix(t(apply(dat1,1,rank,na.last="keep")))
library(gplots)
pdf("plots/forpaper/Supplementary_Figure14_allArrays.pdf")
heatmap(top500r,Colv=NA,ColSideColors=as.character(col1), 
        col=greenred(750),margins=c(1,2), labRow=FALSE,labCol=FALSE)
dev.off()

